.. image:: https://travis-ci.org/ambitioninc/django-manager-utils.png
   :target: https://travis-ci.org/ambitioninc/django-manager-utils

.. image:: https://pypip.in/v/django-manager-utils/badge.png
    :target: https://pypi.python.org/pypi/django-manager-utils/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/django-manager-utils/badge.png
    :target: https://pypi.python.org/pypi/django-manager-utils/
    :alt: Number of PyPI downloads

django-manager-utils
====================
Additional utilities for Django model managers.

Installation
------------
To install the latest release, type::

    pip install django-manager-utils

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-manager-utils.git

Documentation
-------------

Full documentation is available at http://django-manager-utils.readthedocs.org

License
-------
MIT License (see LICENSE)
